@@ -729,6 +729,8 @@ Use the current buffer if nil."
                         "\\|NOTE: Estimated G matrix is not positive definite."
                         "\\|NOTE: Compressing data set .* increased size by"
                         "\\|NOTE: ERROR DETECTED IN ANNOTATE="
+                        "\\|NOTE: Import cancelled.  Output dataset .* already exists."
+			"\\|NOTE: Export cancelled.  Output file"
                         "\\|WARNING: Apparent symbolic reference .* not resolved."
                         "\\|WARNING: Length of character variable has already been set."
                         "\\|WARNING: Not all variables in the list "
